@@ -725,7 +725,6 @@ def _adv_central(
 
     advection = torch.zeros_like(var()[0])
 
-    # BUG: What if var().shape[0] == 1?
     for i in range(var.dim):
         for j in range(var.mesh.dim):
             if isinstance(adv, Jac):
@@ -773,22 +772,6 @@ def _adv_upwind(
     return [Ap, Ac, Am]
 
 
-def _adv_upwind_old(adv: Tensor, var: Field) -> list[list[Tensor]]:
-    """Upwind discretization of the advection term."""
-
-    gamma_min, gamma_max = _gamma_from_adv(adv, var)
-
-    # Here 2.0 is multiplied to achieve consistent implementation of _grad_central_adjust (all coeffs are divided by 2.0 * dx there)
-    Ap = [2.0 * gamma_min for _ in range(var.mesh.dim)]
-    Ac = [2.0 * gamma_max - gamma_min for _ in range(var.mesh.dim)]
-    Am = [-2.0 * gamma_max for _ in range(var.mesh.dim)]
-
-    for i in range(var.dim):
-        _grad_central_adjust(var, [Ap, Ac, Am], i, (gamma_min, gamma_max))
-
-    return [Ap, Ac, Am]
-
-
 def _div_var_j_to_tensor(var_j: Field | Tensor | float | Jac, var_i: Field) -> Tensor:
     """In `Div` operator, convert `var_j` to a `Tensor`. Also check the shape of `var_j` so that is has the same shape of target variable `var_i`."""
 
